@@ -15,13 +15,15 @@ Implementation Notes
 
 **Hardware:**
 
-"* `I2C / SPI character LCD backpack <https://www.adafruit.com/product/292>`_"
+* `I2C / SPI character LCD backpack
+  <https://www.adafruit.com/product/292>`_ (Product ID: 292)
 
 **Software and Dependencies:**
 
-* Adafruit CircuitPython firmware:
-  https://github.com/adafruit/circuitpython/releases
-* Adafruit's Bus Device library (when using I2C/SPI):
+* Adafruit CircuitPython firmware for the supported boards:
+  https://circuitpython.org/downloads
+
+* Adafruit's Bus Device library:
   https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 
 """
@@ -36,18 +38,17 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_CharLCD.git"
 class Character_LCD_I2C(Character_LCD_Mono):
     # pylint: disable=too-few-public-methods, too-many-arguments
     """Character LCD connected to I2C/SPI backpack using its I2C connection.
-    This is a subclass of Character_LCD and implements all of the same
-    functions and functionality.
+    This is a subclass of `Character_LCD_Mono` and implements all of the
+    same functions and functionality.
 
     To use, import and initialise as follows:
 
     .. code-block:: python
 
         import board
-        import busio
         from adafruit_character_lcd.character_lcd_i2c import Character_LCD_I2C
 
-        i2c = busio.I2C(board.SCL, board.SDA)
+        i2c = board.I2C()  # uses board.SCL and board.SDA
         lcd = Character_LCD_I2C(i2c, 16, 2)
     """
 
